Updated constrained convex hull calculation to work with reference raster
Source:R/1.7.4_function_track_UD.R
calculate_constrained_convex_hull_area.RdUpdated constrained convex hull calculation to work with reference raster

R/1.7.4_function_track_UD.R
calculate_constrained_convex_hull_area.RdUpdated constrained convex hull calculation to work with reference raster