Check if a line segment intersects with a box Uses basic line-box intersection algorithm
Source:R/1.7.4_function_track_UD.R
line_intersects_box.RdCheck if a line segment intersects with a box Uses basic line-box intersection algorithm

R/1.7.4_function_track_UD.R
line_intersects_box.RdCheck if a line segment intersects with a box Uses basic line-box intersection algorithm